/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.field.type;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import javax.swing.Action;
import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JToolBar;
import nl.cloudfarming.client.field.model.ActivityField;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.windows.TopComponent;

/**
 * MultiView data element for Activity fields
 *
 * @author Merijn Zengers
 */
@MultiViewElement.Registration(displayName = "#LBL_ACTIVITYFIELD_DATA",
iconBase = "nl/cloudfarming/client/field/type/folder_treatmentzones.png",
mimeType = ActivityField.MIMETYPE,
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "ActivityFieldData",
position = 1000)
@NbBundle.Messages({
    "LBL_ACTIVITYFIELD_DATA=Data",
    "ActivityFieldDataElement_title=Activity field data"
})
public class ActivityFieldDataElement extends JPanel implements MultiViewElement {

    private ASBodyPanel bodyPanel;
    private Lookup lookup;
    private transient MultiViewElementCallback callback;
    private ActivityField activityField;
    private JToolBar toolbar = new JToolBar();
    private NameChangeListener nameChangeListener;

    public ActivityFieldDataElement(Lookup lookup) {
        this.lookup = lookup;
        activityField = lookup.lookup(ActivityField.class);
        assert activityField != null : "ActivityField should be found in the lookup";
    }

    @Override
    public JComponent getVisualRepresentation() {
        if (bodyPanel == null) {
            ActivityFieldDataPanel panel = new ActivityFieldDataPanel(activityField);
            bodyPanel = new ASBodyPanel(panel);
            bodyPanel.setIcon(ImageUtilities.loadImageIcon("nl/cloudfarming/client/field/type/folder_treatmentzones32.png", true));
            bodyPanel.setTitle(Bundle.ActivityFieldDataElement_title());
        }
        return bodyPanel;
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return lookup;
    }

    @Override
    public void componentOpened() {
        nameChangeListener = new NameChangeListener();
        activityField.addPropertyChangeListener(ActivityField.PROP_NAME, nameChangeListener);
    }

    @Override
    public void componentClosed() {
        activityField.removePropertyChangeListener(ActivityField.PROP_NAME, nameChangeListener);
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback mvec) {
        this.callback = mvec;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }

    public void updateName() {
        if (callback != null) {
            String name = activityField.getName();
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(name);
            tc.setDisplayName(name);
            tc.setName(name);
            tc.setToolTipText(getToolTipText());
        }
    }

    /**
     * Listen to changes on {@link ActivityField#PROP_NAME} Updates the name of
     * the topcomponent
     */
    public class NameChangeListener implements PropertyChangeListener {

        @Override
        public void propertyChange(PropertyChangeEvent pce) {
            if (pce.getPropertyName().equals(ActivityField.PROP_NAME)) {
                updateName();
            }
        }
    }
}
