/*
 * Copyright (c) 2012 AgroSense.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    AgroSense - initial API and implementation and/or initial documentation
 */
package nl.cloudfarming.client.field.type;

import com.vividsolutions.jts.geom.Geometry;
import java.util.Date;
import java.util.logging.Level;
import java.util.logging.Logger;
import nl.cloudfarming.client.field.model.Field;
import nl.cloudfarming.client.field.model.FieldManager;
import nl.cloudfarming.client.geoviewer.SplitGeometryHandler;
import nl.cloudfarming.client.model.EnterpriseIdProvider;
import org.netbeans.api.project.Project;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataObject;
import org.openide.loaders.DataObjectNotFoundException;
import org.openide.nodes.Node;
import org.openide.util.Lookup;

/**
 * Split handler for {@link Field}
 * @author johan
 */
public class FieldSplitHandler extends SplitGeometryHandler {
    private static final Logger LOG = Logger.getLogger("nl.cloudfarming.client.field.type");
    private final Field sourceField;

    public FieldSplitHandler(Field field) {
        this.sourceField = field;
    }

    @Override
    public Geometry getSource() {
        return sourceField.getGeometry();
    }

    @Override
    public boolean handle(Geometry[] geometries, Node sourceNode) {
        FieldManager mgr = Lookup.getDefault().lookup(FieldManager.class);
        Project project  = EnterpriseIdProvider.ProjectFinder.find(sourceField.getURI());
        FileObject fieldsFolder = FieldManagerImpl.getFieldsFolder(project, true);

        for (int i = 0; i < geometries.length; i++) {
            // create new field based on original field and new geometry,
            Field newField = new Field(sourceField);
            newField.setGeometry(geometries[i]);
            newField.setName(sourceField.getName() + "-part-" + i);
            
            mgr.save(newField);
            
            FileObject fieldFile = fieldsFolder.getFileObject(newField.getItemIdNumber(), Field.EXT);
            try {
                DataObject dobj = DataObject.find(fieldFile);
                addToMap(dobj.getNodeDelegate());
            } catch (DataObjectNotFoundException ex) {
                LOG.log(Level.WARNING, "could not find dataobject for file {0}: {1}", new Object[]{fieldFile, ex});
            }
        }
        // expire original field:
        sourceField.setEndDate(new Date());
        removeFromMap(sourceNode);
        
        return true;
    }
       
}
