/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.field.type;

import java.awt.datatransfer.Transferable;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.swing.Action;
import nl.cloudfarming.client.field.model.TreatmentZone;
import nl.cloudfarming.client.geoviewer.SingleObjectLayer;
import nl.cloudfarming.client.util.actions.OpenAction;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.Children;
import org.openide.util.Lookup;
import org.openide.util.Utilities;
import org.openide.util.datatransfer.PasteType;
import org.openide.util.lookup.Lookups;

/**
 * Node to display a {@link TreatmentZone}
 *
 * @author Timon Veenstra <monezz@gmail.com>
 */
final class TreatmentZoneNode extends AbstractNode implements PropertyChangeListener, Serializable {

    private TreatmentZone treatmentZone;
    /**
     * Constructs a new node for a {@link TreatmentZone}
     *
     * @param treatmentZone the {@link TreatmentZone} to create this node for
     */
    public TreatmentZoneNode(TreatmentZone treatmentZone) {
        super(Children.LEAF, Lookups.fixed(treatmentZone, new SingleObjectLayer(treatmentZone.getName(), treatmentZone, Lookup.EMPTY), new TreatmentZoneSplitHandler(treatmentZone)));
        assert treatmentZone != null : "Should be a TreatmentZone in the lookup of a TreatmentZonedNode";
        this.treatmentZone = treatmentZone;
        setName(treatmentZone.getName());
        setIconBaseWithExtension("nl/cloudfarming/client/field/type/treatmentzone.png");
        treatmentZone.addPropertyChangeListener(TreatmentZone.PROP_NAME, this);
        
    }

    @Override
    public PasteType getDropType(Transferable t, int action, int index) {
        return null;
    }

    @Override
    public Action[] getActions(boolean context) {
        List<Action> actions = new ArrayList<>();
        actions.add(new OpenAction(TreatmentZone.MIMETYPE, this));
        //add all actions registered in the layer file
        for (Action action : Utilities.actionsForPath("Loaders/application/x-agrosense-treatmentzone/Actions")) {
            actions.add(action);
        }
        
        return actions.toArray(new Action[actions.size()]);
    }

    @Override
    public boolean canRename() {
        return true;
    }

    @Override
    public void setName(String s) {
        super.setName(s);
        treatmentZone.setName(s);
    }

    /**
     * The display name should be the name of the {@link TreatmentZone#name} passed in the constructor
     * @return 
     */
    @Override
    public String getDisplayName() {
        return treatmentZone.getName();
    }
    
    
    
    @Override
    public void propertyChange(PropertyChangeEvent pce) {
        if (pce.getNewValue() != null) {
            this.setName(pce.getNewValue().toString());
        }
    }
}
