/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.field.type;

import java.awt.BorderLayout;
import javax.swing.Action;
import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JToolBar;
import nl.cloudfarming.client.field.model.TreatmentZone;
import nl.cloudfarming.client.geoviewer.render.GeometricalPreviewPanel;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.HelpCtx;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.TopComponent;

/**
 * Visual tab for TreatmentZones
 * @author Gerben Feenstra
 */
@MultiViewElement.Registration(displayName = "#LBL_TreatmentZone_VISUAL",
iconBase = "nl/cloudfarming/client/field/type/treatmentzone.png",
mimeType = TreatmentZone.MIMETYPE,
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "TreatmentZoneVisual",
position = 2000)
@Messages(value={
    "LBL_TreatmentZone_VISUAL=Visual",
    "Title_TreatmentZone_VISUAL=Treatmentzone visual preview"
})
public final class TreatmentZoneVisualElement extends JPanel implements MultiViewElement, HelpCtx.Provider {

    private JToolBar toolbar = new JToolBar();
    private transient MultiViewElementCallback callback;
    private final Lookup lookup;
    

    public TreatmentZoneVisualElement(Lookup lkp) {
        this.lookup=  lkp;
        
        TreatmentZone treatmentZone = lkp.lookup(TreatmentZone.class);
        assert treatmentZone != null:" lookup should contain a TreatmentZone Object";

        this.setLayout(new BorderLayout());
        ASBodyPanel contentPanel = new ASBodyPanel(new GeometricalPreviewPanel(treatmentZone));
        contentPanel.setTitle(Bundle.Title_TreatmentZone_VISUAL());
        contentPanel.setIcon(ImageUtilities.loadImageIcon("nl/cloudfarming/client/field/type/treatmentzone32.png", true));
        add(contentPanel);
    }

    @Override
    public String getName() {
        return "TreatmentZoneVisualElement";
    }

    @Override
    public JComponent getVisualRepresentation() {
        return this;
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public void componentOpened() {
    }

    @Override
    public void componentClosed() {
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback callback) {
        this.callback = callback;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }

    /**
     * Displays tab-name when component is showed.
     */
    private void updateName() {
        if (callback != null) {
            TreatmentZone treatmentZone = getLookup().lookup(TreatmentZone.class);
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(treatmentZone.getName());
            tc.setDisplayName(treatmentZone.getName());
            tc.setName(getName());
            tc.setToolTipText(getToolTipText());
        }
    }
    
    @Override
    public HelpCtx getHelpCtx() {
        return new HelpCtx("nl.cloudfarming.client.treatmentZone.type.about");
    } 

    @Override
    public Lookup getLookup() {
        return lookup;
    }
}
