/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.field.type.wizard;

import java.awt.Dimension;
import java.util.ArrayList;
import java.util.List;
import javax.swing.event.ChangeListener;
import nl.cloudfarming.client.geoviewer.Geometrical;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.api.project.Project;
import org.openide.WizardDescriptor;
import org.openide.util.HelpCtx;
import org.openide.util.NbBundle.Messages;

@Messages({
    "GeometricalTaskObjectSelectWizardSummaryPanel_title=Selection summary",
    "selectFieldSummary=Summary",
})
public class GeometricalSelectSummaryController implements WizardDescriptor.Panel<WizardDescriptor> {

    /**
     * The visual component that displays this panel. If you need to access the
     * component from this class, just use getComponent().
     */
    private GeometricalSelectSummaryPanel visualPanel;
    private ASBodyPanel component;
    public static final String DEF_PROJECT_PATH_VALUE = "noProject";
    public static final String PANEL_TITLE = Bundle.GeometricalTaskObjectSelectWizardSummaryPanel_title();
    private WizardDescriptor wizardDescriptor = null;
    private List<Geometrical> geometricals = new ArrayList<>();
      
    public GeometricalSelectSummaryController(List<Geometrical> geometricals, Project project){
        visualPanel = new GeometricalSelectSummaryPanel();
        visualPanel.setSelectedProjectPath(project.getProjectDirectory().getPath());
        visualPanel.setGeometricals(geometricals);
        this.geometricals = geometricals;
    }
    
    // Get the visual component for the panel. In this template, the component
    // is kept separate. This can be more efficient: if the wizard is created
    // but never displayed, or not all panels are displayed, it is better to
    // create only those which really need to be visible.
    @Override
    public ASBodyPanel getComponent() {
        if (component == null) {
            component = new ASBodyPanel(visualPanel);
            component.setMinimumSize(new Dimension(GeometricalSelectUtil.PROP_WIZARD_WIDTH, GeometricalSelectUtil.PROP_WIZARD_HEIGHT));
            component.setName(visualPanel.getName());
            component.setTitle(Bundle.selectFieldSummary());
        }
        return component;
    }

    @Override
    public HelpCtx getHelp() {
        // Show no Help button for this panel:
        return HelpCtx.DEFAULT_HELP;
        // If you have context help:
        // return new HelpCtx("help.key.here");
    }

    @Override
    public boolean isValid() {
        if(wizardDescriptor == null){
            visualPanel.setValid(false);
            return false;
        }
        if(geometricals == null || geometricals.isEmpty()) {
            visualPanel.setValid(false);
            return false;
        }
        visualPanel.setValid(true);
        return true;
    }

    @Override
    public void addChangeListener(ChangeListener l) {
    }

    @Override
    public void removeChangeListener(ChangeListener l) {
    }

    /**
     * Used to retrieve previous panel state. Not implemented for this panel.
     * @param wiz 
     */
    @Override
    public void readSettings(WizardDescriptor wiz) {
        wizardDescriptor = wiz;
    }

    /**
     * Store selected Geometricals and selected project in the wizardDescriptor for retrievel after this wizard finishes.
     * Not used for this panel
     * @param wiz 
     */
    @Override
    public void storeSettings(WizardDescriptor wiz) {
    }
}
