/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.field.type.wizard;

import java.awt.Component;
import java.awt.Dimension;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Logger;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.event.ChangeListener;
import nl.cloudfarming.client.field.model.Field;
import nl.cloudfarming.client.field.model.TreatmentZone;
import nl.cloudfarming.client.geoviewer.Geometrical;
import org.netbeans.api.project.Project;
import org.openide.WizardDescriptor;
import org.openide.filesystems.*;
import org.openide.util.HelpCtx;

/**
 *
 * @author Gerben Feenstra
 */
public class GeometricalSelectUtil {
    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.field.type.wizard");
    public static final String PROP_SELECTED_GEOMETRICALS = "PropSelectedFields";
    public static final String PROP_SELECTED_PROJECT = "PropSelectedProject";
    public static final String PROP_BITMAP = "SelectedBitMap";
    public static final int PROP_WIZARD_HEIGHT = 400;
    public static final int PROP_WIZARD_WIDTH = 600;
    
    private GeometricalSelectUtil(){}
          
    /**
     * Clear stored preferences for the specified WizardDescriptor
     * @param wiz 
     */
    protected static void clearStoredPreferences(WizardDescriptor wiz) {
        wiz.putProperty(PROP_SELECTED_GEOMETRICALS, null);
        wiz.putProperty(PROP_SELECTED_PROJECT, null);
        wiz.putProperty(PROP_BITMAP, null);
    }
    
   /**
    * Add specified geometricals to the active task in context of the specified project.
    * TODO: FIX THIS WAY OF ADDING ITEMS TO A TASK. 
    * @param geometricals
    * @param project 
    * @param type 
    * @deprecated This can be done nicer
    */
    @Deprecated
    public static void addGeometricalsToActiveTask(List<Geometrical> geometricals, Project project, Class type) {
        List<String> geometricalPaths = getGeometricalPaths(geometricals);
        String projectPath = FileUtil.toFile(project.getProjectDirectory()).getPath();
        if (geometricalPaths != null) {
            for (String aproximatePath : geometricalPaths) {
                //FIXME how to add geometricals to a task??
//                String productPath = getFullGeometricalPath(aproximatePath, project);
//                TaskService.getInstance().addContextItemToActiveTask(productPath, projectPath);
            }
        }
    }
    
    /**
     * Get a list of paths of the specified geometricals
     * @param geometricals
     * @return 
     * @deprecated For the same reason as addGeometricalsToActiveTask()
     */
    @Deprecated
    public static List<String> getGeometricalPaths(List<Geometrical> geometricals) {
        List<String> geometricalPaths = new ArrayList<>();
        if (geometricals == null) {
            return geometricalPaths;
        }
        for (Geometrical geometrical : geometricals) {
            if (geometrical instanceof Field) {
                geometricalPaths.add(((Field) geometrical).getName() + "." + Field.EXT);
            } else {
                geometricalPaths.add(((TreatmentZone) geometrical).getName() + "." + TreatmentZone.EXT);
            }
        }
        return geometricalPaths;
    }


        
    /**
     * Empty panel containing a single message.
     */
    static public class MessagePanel implements WizardDescriptor.Panel {

        private JPanel dummyPanel = new JPanel();
        
        public MessagePanel(String message, String panelName){
            dummyPanel.setMinimumSize(new Dimension(GeometricalSelectUtil.PROP_WIZARD_WIDTH, GeometricalSelectUtil.PROP_WIZARD_HEIGHT));
            dummyPanel.setName(panelName);
            dummyPanel.add(new JLabel(message));
        }
        
        @Override
        public Component getComponent() {
            return dummyPanel;
        }

        @Override
        public HelpCtx getHelp() {
            return null;
        }

        @Override
        public void readSettings(Object settings) {
        }

        @Override
        public void storeSettings(Object settings) {
        }

        @Override
        public boolean isValid() {
            return false;
        }

        @Override
        public void addChangeListener(ChangeListener l) {
        }

        @Override
        public void removeChangeListener(ChangeListener l) {
        }
    }
}
